Contributors
============

The follow people have contributed directly to this project:

- `Andrew Brookes <https://github.com/brookesey>`_
- `Andrew Crozier <https://github.com/acroz>`_
- `Pascal Bugnion <https://github.com/pbugnion>`_
- `Peter Foster <https://github.com/pafoster>`_
- `Scott Stevenson <https://github.com/srstevenson>`_
- `Setrak Balian <https://github.com/sbailan>`_
- `Víctor Zabalza <https://github.com/zblz>`_
